@@ -1,4 +1,4 @@
-/* $Id: lint.h,v 1.14 2010/06/13 12:37:40 bzfkocht Exp $ */
+/* $Id: lint.h,v 1.18 2012/07/29 15:09:27 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: lint.h                                                        */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2012 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* Use this file only if we are linting
@@ -32,6 +32,10 @@
 #ifndef _LINT_H_
 #define _LINT_H_
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /* Unfortunately strdup() is not a POSIX function.
  */
 /*lint -sem(strdup, 1p && nulterm(1), @P == malloc(1P) && nulterm(@p)) */ 
@@ -86,6 +90,9 @@ extern int    gzgetc(gzFile file);
 /*lint -sem(  gzclose, 1p == 1) */
 extern int    gzclose(gzFile file);
 
+#ifdef __cplusplus
+}
+#endif
 #endif /* _LINT_H_ */
 #endif /* _lint */
 
