@@ -100,48 +100,53 @@
      POW = 316,
      FAC = 317,
      CARD = 318,
-     ABS = 319,
-     SGN = 320,
-     ROUND = 321,
-     FLOOR = 322,
-     CEIL = 323,
-     LOG = 324,
-     LN = 325,
-     EXP = 326,
-     SQRT = 327,
-     RANDOM = 328,
-     ORD = 329,
-     READ = 330,
-     AS = 331,
-     SKIP = 332,
-     USE = 333,
-     COMMENT = 334,
-     MATCH = 335,
-     SUBSETS = 336,
-     INDEXSET = 337,
-     POWERSET = 338,
-     VIF = 339,
-     VABS = 340,
-     TYPE1 = 341,
-     TYPE2 = 342,
-     LENGTH = 343,
-     SUBSTR = 344,
-     NUMBSYM = 345,
-     STRGSYM = 346,
-     VARSYM = 347,
-     SETSYM = 348,
-     NUMBDEF = 349,
-     STRGDEF = 350,
-     BOOLDEF = 351,
-     SETDEF = 352,
-     DEFNAME = 353,
-     NAME = 354,
-     STRG = 355,
-     NUMB = 356,
-     SCALE = 357,
-     SEPARATE = 358,
-     CHECKONLY = 359,
-     INDICATOR = 360
+     ROUND = 319,
+     FLOOR = 320,
+     CEIL = 321,
+     RANDOM = 322,
+     ORD = 323,
+     ABS = 324,
+     SGN = 325,
+     LOG = 326,
+     LN = 327,
+     EXP = 328,
+     SQRT = 329,
+     SIN = 330,
+     COS = 331,
+     TAN = 332,
+     POWER = 333,
+     SGNPOW = 334,
+     READ = 335,
+     AS = 336,
+     SKIP = 337,
+     USE = 338,
+     COMMENT = 339,
+     MATCH = 340,
+     SUBSETS = 341,
+     INDEXSET = 342,
+     POWERSET = 343,
+     VIF = 344,
+     VABS = 345,
+     TYPE1 = 346,
+     TYPE2 = 347,
+     LENGTH = 348,
+     SUBSTR = 349,
+     NUMBSYM = 350,
+     STRGSYM = 351,
+     VARSYM = 352,
+     SETSYM = 353,
+     NUMBDEF = 354,
+     STRGDEF = 355,
+     BOOLDEF = 356,
+     SETDEF = 357,
+     DEFNAME = 358,
+     NAME = 359,
+     STRG = 360,
+     NUMB = 361,
+     SCALE = 362,
+     SEPARATE = 363,
+     CHECKONLY = 364,
+     INDICATOR = 365
    };
 #endif
 /* Tokens.  */
@@ -206,48 +211,53 @@
 #define POW 316
 #define FAC 317
 #define CARD 318
-#define ABS 319
-#define SGN 320
-#define ROUND 321
-#define FLOOR 322
-#define CEIL 323
-#define LOG 324
-#define LN 325
-#define EXP 326
-#define SQRT 327
-#define RANDOM 328
-#define ORD 329
-#define READ 330
-#define AS 331
-#define SKIP 332
-#define USE 333
-#define COMMENT 334
-#define MATCH 335
-#define SUBSETS 336
-#define INDEXSET 337
-#define POWERSET 338
-#define VIF 339
-#define VABS 340
-#define TYPE1 341
-#define TYPE2 342
-#define LENGTH 343
-#define SUBSTR 344
-#define NUMBSYM 345
-#define STRGSYM 346
-#define VARSYM 347
-#define SETSYM 348
-#define NUMBDEF 349
-#define STRGDEF 350
-#define BOOLDEF 351
-#define SETDEF 352
-#define DEFNAME 353
-#define NAME 354
-#define STRG 355
-#define NUMB 356
-#define SCALE 357
-#define SEPARATE 358
-#define CHECKONLY 359
-#define INDICATOR 360
+#define ROUND 319
+#define FLOOR 320
+#define CEIL 321
+#define RANDOM 322
+#define ORD 323
+#define ABS 324
+#define SGN 325
+#define LOG 326
+#define LN 327
+#define EXP 328
+#define SQRT 329
+#define SIN 330
+#define COS 331
+#define TAN 332
+#define POWER 333
+#define SGNPOW 334
+#define READ 335
+#define AS 336
+#define SKIP 337
+#define USE 338
+#define COMMENT 339
+#define MATCH 340
+#define SUBSETS 341
+#define INDEXSET 342
+#define POWERSET 343
+#define VIF 344
+#define VABS 345
+#define TYPE1 346
+#define TYPE2 347
+#define LENGTH 348
+#define SUBSTR 349
+#define NUMBSYM 350
+#define STRGSYM 351
+#define VARSYM 352
+#define SETSYM 353
+#define NUMBDEF 354
+#define STRGDEF 355
+#define BOOLDEF 356
+#define SETDEF 357
+#define DEFNAME 358
+#define NAME 359
+#define STRG 360
+#define NUMB 361
+#define SCALE 362
+#define SEPARATE 363
+#define CHECKONLY 364
+#define INDICATOR 365
 
 
 
@@ -265,7 +275,7 @@ typedef union YYSTYPE
    CodeNode*    code;
 }
 /* Line 1489 of yacc.c.  */
-#line 269 "src/mmlparse2.h"
+#line 279 "src/mmlparse2.h"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
