@@ -1,4 +1,4 @@
-/* $Id: ratmpswrite.c,v 1.20 2010/06/13 12:37:41 bzfkocht Exp $ */
+/* $Id: ratmpswrite.c,v 1.24 2012/07/29 15:09:29 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: mpswrite.c                                                    */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2012 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <stdio.h>
@@ -115,9 +115,12 @@ static void write_vars(
 
             if (first)
             {
-               fprintf(stderr, "%s\n%s\n",
-                  "--- Warning: Objective function inverted to make",
-                  "             minimization problem for MPS output\n");
+               if (verbose > 0)
+               {
+                  fprintf(stderr, "%s\n%s\n",
+                     "--- Warning: Objective function inverted to make",
+                     "             minimization problem for MPS output\n");
+               }
                first = FALSE;
             }
          }
