@@ -1,4 +1,4 @@
-/* $Id: setempty.c,v 1.9 2010/06/13 12:37:41 bzfkocht Exp $ */
+/* $Id: setempty.c,v 1.14 2012/07/29 15:09:29 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: setempty.c                                                    */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2001-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2001-2012 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <stdio.h>
@@ -37,8 +37,12 @@
 #include "tuple.h"
 #include "mme.h"
 #include "hash.h"
-#include "set4.h"
 #include "set.h"
+#include "set4.h"
+
+#ifdef _MSC_VER
+#pragma warning (disable: 4100) /* unreferenced formal parameter */
+#endif
 
 #define SET_EMPTY_SID          0x5345544f
 #define SET_EMPTY_ITER_SID     0x53454f49
