@@ -1,4 +1,4 @@
-/* $Id: zimpllib.c,v 1.27 2010/09/30 11:13:28 bzfkocht Exp $ */
+/* $Id: zimpllib.c,v 1.32 2012/07/29 15:09:31 bzfkocht Exp $ */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*   File....: zimpllib.c                                                    */
@@ -8,7 +8,7 @@
 /*                                                                           */
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*
- * Copyright (C) 2005-2010 by Thorsten Koch <koch@zib.de>
+ * Copyright (C) 2005-2012 by Thorsten Koch <koch@zib.de>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -22,7 +22,7 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <sys/types.h>
@@ -38,6 +38,7 @@
 #include "lint.h"
 #include "bool.h"
 #include "mshell.h"
+#include "stkchk.h"
 #include "blkmem.h"
 #include "random.h"
 #include "ratlptypes.h"
@@ -74,7 +75,7 @@ void zpl_print_banner(FILE* fp, Bool with_license)
    const char* const banner = 
       "****************************************************\n" \
       "* Zuse Institute Mathematical Programming Language *\n" \
-      "* Release %-5s Copyright (C)2009 by Thorsten Koch *\n" \
+      "* Release %-5s Copyright (C)2012 by Thorsten Koch *\n" \
       "****************************************************\n";
 
    const char* const license = 
@@ -125,10 +126,10 @@ static Bool is_valid_identifier(const char* s)
 
 void zpl_var_print(FILE* fp, const Var* var)
 {
-   const char* name  = xlp_getvarname(var);
-   VarClass    class = xlp_getclass(var);
-   Bound*      lower = xlp_getlower(var);
-   Bound*      upper = xlp_getupper(var);
+   const char* name  = xlp_getvarname(prog_get_lp(), var);
+   VarClass    class = xlp_getclass(prog_get_lp(), var);
+   Bound*      lower = xlp_getlower(prog_get_lp(), var);
+   Bound*      upper = xlp_getupper(prog_get_lp(), var);
 
    fprintf(fp, "\"%s\" ", name);
 
@@ -183,7 +184,8 @@ void zpl_add_parameter(const char* def)
 
    if (strlen(name) == 0 || strlen(value) == 0 || !is_valid_identifier(name))
    {
-      fprintf(stderr, warning, def);
+      if (verbose > VERB_QUIET)
+         fprintf(stderr, warning, def);
       free(name);
       return;
    }
@@ -206,11 +208,14 @@ void zpl_add_parameter(const char* def)
    free(name); 
 }
 
-Bool zpl_read(const char* filename, Bool with_management)
+Bool zpl_read(const char* filename, Bool with_management, void* user_data)
 {
    Prog*       prog = NULL;
    Set*        set;
+   void*       lp  = NULL;
    Bool        ret = FALSE;
+
+   stkchk_init();
    
    yydebug       = 0;
    yy_flex_debug = 0;
@@ -246,16 +251,17 @@ Bool zpl_read(const char* filename, Bool with_management)
          if (verbose >= VERB_DEBUG)
             prog_print(stderr, prog);
    
-         xlp_alloc(filename, FALSE);
+         lp = xlp_alloc(filename, FALSE, user_data);
 
-         prog_execute(prog);
+         prog_execute(prog, lp);
 
          ret = TRUE;
       }
    }
    is_longjmp_ok = FALSE;
 
-   xlp_free();
+   if (lp != NULL)
+      xlp_free(lp);
 
    if (prog != NULL)
       prog_free(prog);
@@ -274,7 +280,7 @@ Bool zpl_read(const char* filename, Bool with_management)
    return ret;
 }
 
-Bool zpl_read_with_args(char** argv, int argc, Bool with_management)
+Bool zpl_read_with_args(char** argv, int argc, Bool with_management, void* user_data)
 {
    const char* options = "D:mP:sv:";
 
@@ -285,10 +291,13 @@ Bool zpl_read_with_args(char** argv, int argc, Bool with_management)
    int           i;
    Prog*         prog = NULL;
    Set*          set;
+   void*         lp  = NULL;
    Bool          ret = FALSE;
    char*         inppipe = NULL;
    Bool          use_startval = FALSE;
    
+   stkchk_init();
+
    yydebug       = 0;
    yy_flex_debug = 0;
    param_table   = malloc(sizeof(*param_table));
@@ -377,16 +386,17 @@ Bool zpl_read_with_args(char** argv, int argc, Bool with_management)
          if (verbose >= VERB_DEBUG)
             prog_print(stderr, prog);
    
-         xlp_alloc(argv[optind], use_startval);
+         lp = xlp_alloc(argv[optind], use_startval, user_data);
 
-         prog_execute(prog);
+         prog_execute(prog, lp);
 
          ret = TRUE;
       }
    }
    is_longjmp_ok = FALSE;
 
-   xlp_free();
+   if (lp != NULL)
+      xlp_free(lp);
 
    /* Now clean up. 
     */
